@@ -1263,7 +1263,7 @@ sub _palette    # (frame, card_canvas, \current_hole, \threading, update)
             my $title = "Select new color to add to palette";
             my $color = $self->color_dlog->Show( -title => $title );
             return unless defined $color;
-            $self->color_table( undef, $color );
+            $self->pattern->color_table( undef, $color );
             $self->refresh_color_list($h);
         },
     )->pack(qw/-side top/);
@@ -1285,7 +1285,7 @@ sub _palette    # (frame, card_canvas, \current_hole, \threading, update)
             )->pack;
             return if $d->Show eq 'Cancel';
             return if $cname   eq '';
-            $self->color_table( undef, $cname );
+            $self->pattern->color_table( undef, $cname );
             $self->refresh_color_list($h);
         },
     )->pack(qw/-side top/);
@@ -1304,7 +1304,7 @@ sub _palette    # (frame, card_canvas, \current_hole, \threading, update)
                 -initialcolor => $self->color_table($s),
             );
             return unless defined $color;
-            $self->color_table( $s, $color );
+            $self->pattern->color_table( $s, $color );
             $h->itemConfigure( $s, 1, -text => $color );
             $self->update_pattern;
             $self->refresh_card_threading($card_canvas) if $update;
@@ -1327,7 +1327,7 @@ sub _palette    # (frame, card_canvas, \current_hole, \threading, update)
         -browsecmd => sub {
             $$threading[$$current_hole] = shift;
             $card_canvas->itemconfigure( "hole$$current_hole",
-                -fill => $self->color_table( $$threading[$$current_hole] ) );
+                -fill => $self->pattern->color_table( $$threading[$$current_hole] ) );
 
         },
     ) if $update eq 'new';
@@ -1364,7 +1364,7 @@ sub _palette    # (frame, card_canvas, \current_hole, \threading, update)
             print "change $old ($s at $y) to $new\n";
             return if $old eq $new;
             return if $new eq '';
-            $self->color_table( $s, $new );
+            $self->pattern->color_table( $s, $new );
             $h->itemConfigure( $s, 1, -text => $new );
             $self->update_pattern;
             $self->refresh_card_threading($card_canvas) if $update;
@@ -1869,11 +1869,11 @@ sub insert_card_dlog
                 my $after_card =
                     $d_info->{where} eq 'bottom'  ? 0
                   : $d_info->{where} eq 'current' ? $d_info->{where_card}
-                  :                                 $self->number_of_cards;
+                  :                                 $self->pattern->number_of_cards;
                 if (
                     $d_info->{where} eq 'current'
                     and (  $after_card < 0
-                        or $after_card > $self->number_of_cards )
+                        or $after_card > $self->pattern->number_of_cards )
                   )
                 {
                     $d->Dialog( -text =>
@@ -1903,11 +1903,11 @@ sub insert_card_dlog
                 my $after_card =
                     $d_info->{where} eq 'bottom'  ? 0
                   : $d_info->{where} eq 'current' ? $d_info->{where_card}
-                  :                                 $self->number_of_cards;
+                  :                                 $self->pattern->number_of_cards;
                 if (
                     $d_info->{where} eq 'current'
                     and (  $after_card < 0
-                        or $after_card > $self->number_of_cards )
+                        or $after_card > $self->pattern->number_of_cards )
                   )
                 {
                     $d->Dialog( -text =>
@@ -2199,11 +2199,11 @@ sub delete_card_dlog
                 my $after_card =
                     $d_info->{where} eq 'bottom'  ? 1
                   : $d_info->{where} eq 'current' ? $d_info->{where_card}
-                  :                                 $self->number_of_cards;
+                  :                                 $self->pattern->number_of_cards;
                 if (
                     $d_info->{where} eq 'current'
                     and (  $after_card < 0
-                        or $after_card > $self->number_of_cards )
+                        or $after_card > $self->pattern->number_of_cards )
                   )
                 {
                     $d->Dialog( -text =>
@@ -2213,10 +2213,10 @@ sub delete_card_dlog
                 }
                 print "delete_card($after_card-1)\n";
                 $self->canvas->delete(
-                    "card" . ( $self->number_of_cards - 1 ) );
-                $self->delete_card( $after_card - 1 );
-                $self->current_card( $self->number_of_cards - 1 )
-                  if $self->current_card >= $self->number_of_cards;
+                    "card" . ( $self->pattern->number_of_cards - 1 ) );
+                $self->pattern->delete_card( $after_card - 1 );
+                $self->current_card( $self->pattern->number_of_cards - 1 )
+                  if $self->current_card >= $self->pattern->number_of_cards;
                 $self->draw_pattern;
                 $d->withdraw;
             },
@@ -2301,10 +2301,10 @@ sub duplicate_card_dlog
                 my $from_card =
                     $d_info->{from} eq 'bottom'  ? 1
                   : $d_info->{from} eq 'current' ? $d_info->{from_card}
-                  :                                $self->number_of_cards;
+                  :                                $self->pattern->number_of_cards;
                 if ( $d_info->{from} eq 'current'
                     and
-                    ( $from_card < 0 or $from_card > $self->number_of_cards ) )
+                    ( $from_card < 0 or $from_card > $self->pattern->number_of_cards ) )
                 {
                     $d->Dialog( -text =>
 '"From" card must be between 1 and the number of turns'
@@ -2314,11 +2314,11 @@ sub duplicate_card_dlog
                 my $after_card =
                     $d_info->{after} eq 'bottom'  ? 0
                   : $d_info->{after} eq 'current' ? $d_info->{after_card}
-                  :                                 $self->number_of_cards;
+                  :                                 $self->pattern->number_of_cards;
                 if (
                     $d_info->{after} eq 'current'
                     and (  $after_card < 0
-                        or $after_card > $self->number_of_cards )
+                        or $after_card > $self->pattern->number_of_cards )
                   )
                 {
                     $d->Dialog( -text =>
@@ -2338,10 +2338,10 @@ sub duplicate_card_dlog
                 my $from_card =
                     $d_info->{from} eq 'bottom'  ? 1
                   : $d_info->{from} eq 'current' ? $d_info->{from_card}
-                  :                                $self->number_of_cards;
+                  :                                $self->pattern->number_of_cards;
                 if ( $d_info->{from} eq 'current'
                     and
-                    ( $from_card < 0 or $from_card > $self->number_of_cards ) )
+                    ( $from_card < 0 or $from_card > $self->pattern->number_of_cards ) )
                 {
                     $d->Dialog( -text =>
 '"From" card must be between 1 and the number of turns'
@@ -2351,11 +2351,11 @@ sub duplicate_card_dlog
                 my $after_card =
                     $d_info->{after} eq 'bottom'  ? 0
                   : $d_info->{after} eq 'current' ? $d_info->{after_card}
-                  :                                 $self->number_of_cards;
+                  :                                 $self->pattern->number_of_cards;
                 if (
                     $d_info->{after} eq 'current'
                     and (  $after_card < 0
-                        or $after_card > $self->number_of_cards )
+                        or $after_card > $self->pattern->number_of_cards )
                   )
                 {
                     $d->Dialog( -text =>
